/* Visibone-alt-2 by Gutterslob from http://terminal.sexy  */
$fg: #cccccc
$bg: #333333

$colors: #666666, #cc6699, #99cc66, #cc9966, #6699cc, #9966cc, #66cc99, #cccccc, #999999, #ff99cc, #ccff99, #ffcc99, #99ccff, #cc99ff, #99ffcc, #ffffff

@import variables
@import styles
